configurationtools.list_package_dependency_versions
===================================================

.. autofunction:: abjad.tools.configurationtools.list_package_dependency_versions.list_package_dependency_versions
